## Settings
palette("default")

update_geom_defaults("bar",   list(fill = "grey70", colour = "grey40"))
scale_colour_discrete <- function(...) scale_colour_brewer(..., palette="Set2")
scale_fill_discrete <- function(...) scale_fill_colorblind()
auTheme <- theme_grey()  + 
    theme(panel.background =   element_rect(colour = NA, fill = "grey90")) +
    theme(plot.background =   element_rect(colour = NA, fill = "grey90")) +
    theme(legend.background =   element_rect(fill = "grey90")) +
    theme(plot.title = element_text(vjust = 2)) 
theme_set(auTheme)

## ----strHIa------------------------------------------------
data(HI, package="Ecdat")
str(HI, vec.len=2, width = 60, strict.width="wrap")

## ----strHIb----
## with(HI[HI$husby > 98 & HI$husby < 102 ,], table(husby))

## ----HIhists----
library(reshape2)
HIvs <- c("whrswk", "experience", "husby", "wght")
HIs <- melt(HI[, HIvs], value.name = "HIx",
            variable.name = "HIvars")
ggplot(HIs, aes(HIx)) + geom_histogram() +
       facet_wrap(~ HIvars, scales = "free") +
       xlab("") + ylab("")

## ----HIbars----
uniqv <- function(x) length(unique(x)) < 20
vcs <- names(HI)[sapply(HI, uniqv)]
par(mfrow = n2mfrow(length(vcs)))
relativeWeight <- with(HI, wght/sum(as.numeric(wght))*100)
for(v in vcs) 
    barplot(tapply(relativeWeight, HI[[v]], sum), main = v)

## ----BarchartsBoston----
data(Boston, package="MASS")
par(mfrow=c(1,2))
for (i in c("chas", "rad")) {
     barplot(table(Boston[, i]),
     main=(paste("Barchart of", i)))
 }

## ----HistsBoston----
vs1 <- !(names(Boston) %in% c("chas","rad"))
grs <- n2mfrow(sum(as.numeric(vs1)))
par(mfrow=grs)
for (i in names(Boston)[vs1]) {
     hist(Boston[,i], col="grey70", xlab="", ylab="",
     main=(paste("Histogram of", i)))
     }

## ----splomBoston----
plot(Boston, pch=16)

## ----pcpBoston----
data(Boston, package="MASS")
par(mfrow=c(1,1), mar=c(3.1, 1.1, 2.1, 1.1))
MASS::parcoord(Boston)

## ----heatBoston----
library(gplots)
heatmap.2(as.matrix(Boston), scale="column", trace="none")

## ----glyphBostonS----
par(mar=c(1.1, 1.1, 1.1, 1.1))
palette(rainbow(14, s = 0.6, v = 0.75))
stars(Boston[1:4,], labels=NULL, draw.segments = TRUE)

## ----glyphBoston----
stars(Boston, labels=NULL, draw.segments = TRUE)

## ----ratMos----
data(foster, package="HSAUR2")
mosaic(~litgen+motgen, data=foster)

## ----ratMB----
ggplot(data=foster, aes(motgen)) + geom_bar() + 
       facet_grid(litgen~ .) + xlab("") + ylab("") +
       scale_y_continuous(breaks=seq(0,6,3)) + 
       labs(title="litter genotype by mother's genotype")

## ----latticeBarley----
library(lattice)
data(barley, package="lattice")
dotplot(site ~ yield |variety , data = barley,
        groups = year, columns=2, pch=16, col=c("red","blue"),
        key = list(text=list(levels(barley$year)),
        points = list(pch=16, col=c("red", "blue"))),
        xlab = "Barley Yield (bushels/acre) ", ylab=NULL,
        main="Barley Yields by Site for ten Varieties")

## ----uniRgroups----
data(uniranks, package="GDAdata")
names(uniranks)[c(5, 6, 8, 9, 10, 11, 13)] <- c("AvTeach", "NSSTeach", "SpendperSt", "StudentStaffR",
                                                "Careers", "VAddScore", "NSSFeedb")
ur2 <- melt(uniranks[, c(3, 5:13)], id.vars="UniGroup", variable.name="uniV", value.name="uniX")
ggplot(ur2, aes(uniX)) + geom_histogram() + xlab("") +  ylab("") +
       facet_grid(UniGroup~uniV, scales = "free_x")

